dag_cbor.ipld
=============

.. automodule:: dag_cbor.ipld

IPLDKind
--------

.. autodata:: dag_cbor.ipld.IPLDKind

IPLDScalarKind
--------------

.. autodata:: dag_cbor.ipld.IPLDScalarKind

ObjPath
-------

.. autoclass:: dag_cbor.ipld.ObjPath
    :show-inheritance:
    :members:
    :special-members: __new__, __truediv__, __rtruediv__, __le__, __lt__, __repr__, __rshift__

ObjPathSegment
--------------

.. autodata:: dag_cbor.ipld.ObjPathSegment
